# pdxloc

_pdxloc_ is a library that provides python functions related to manipulating
Paradox games' localization files.

Current features:
 * Read/write localization files

## Requirements

 * Python 3.9 or newer

## Installation

`pip install pdxloc`

## Samples

Take a look at the [samples](samples) directory for use-cases.

## Limitations

### Windows - non-English

Windows does not support non-English characters

## License

This project is licensed, see the [LICENSE](LICENSE) file for details.
